<?php
/**
* HTMLƥʥ֥ȥ饹
*
* PHP version 5
*
* @package    html_objects
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

abstract class HTMLContainerObject extends HTMLObject
{
	protected $_children;

	/*
	 *	󥹥ȥ饯
	 */
	public function __construct( $tag, $attributes )
	{
		parent::__construct( $tag, $attributes );

		$this->_children     = array();
	}

	/*
	 *	Ǥɲ
	 */
	public function addChild( HTMLObject $child )
	{
		$this->_children[] = $child;
	}

	/*
	 *	HTML
	 */
	public function toHTML()
	{
		// ϥ
		$html = $this->startTag() . PHP_EOL;

		// Ǥν
		$html .= $this->childTags() . PHP_EOL;

		// λ
		$html .= $this->endTag() . PHP_EOL;

		return $html;
	}
  
	/*
	 *	ǥ
	 */
	public function childTags()
	{
		$html = '';
		$children = $this->_children;
		foreach( $children as $c ){
			$html .= $c->toHTML();
		}
		return $html;
	}

	/*
	 *	
	 */
	public function dump( $indent = 0 )
	{
		$children = $this->_children;
		foreach( $children as $c ){
			print str_repeat('&nbsp;',$indent*4) . get_class($c) . "<BR>";
			if ( $c instanceof HTMLContainerObject ){
				$c->dump( $indent + 1 );
			}
		}
	}

}

return __FILE__;